@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2020 Roberto Alsina and others.
+# Copyright © 2012-2021 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -30,12 +30,14 @@ import importlib.util
 import os
 import shutil
 import sys
+import textwrap
 import traceback
+import doit.cmd_base
 from collections import defaultdict
 
 from blinker import signal
 from doit.cmd_auto import Auto as DoitAuto
-from doit.cmd_base import TaskLoader
+from doit.cmd_base import TaskLoader, _wrap
 from doit.cmd_clean import Clean as DoitClean
 from doit.cmd_completion import TabCompletion
 from doit.cmd_help import Help as DoitHelp
@@ -111,7 +113,7 @@ def main(args=None):
             os.chdir(root)
         # Help and imports don't require config, but can use one if it exists
         needs_config_file = (argname != 'help') and not argname.startswith('import_')
-        LOGGER.debug("Website root: {0!r}", root)
+        LOGGER.debug("Website root: %r", root)
     else:
         needs_config_file = False
 
@@ -227,7 +229,7 @@ class Build(DoitRun):
             }
         )
         self.cmd_options = tuple(opts)
-        super(Build, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
 
 
 class Clean(DoitClean):
@@ -296,7 +298,7 @@ class DoitNikola(DoitMain):
 
     def __init__(self, nikola, quiet=False):
         """Initialzie DoitNikola."""
-        super(DoitNikola, self).__init__()
+        super().__init__()
         self.nikola = nikola
         nikola.doit = self
         self.task_loader = self.TASK_LOADER(nikola, quiet)
@@ -366,7 +368,7 @@ class DoitNikola(DoitMain):
                              "existing Nikola site.")
                 return 3
         try:
-            return super(DoitNikola, self).run(cmd_args)
+            return super().run(cmd_args)
         except Exception:
             LOGGER.error('An unhandled exception occurred.')
             if self.nikola.debug or self.nikola.show_tracebacks:
@@ -380,6 +382,53 @@ class DoitNikola(DoitMain):
         print("Nikola v" + __version__)
 
 
+# Override Command.help() to make it more readable and to remove
+# some doit-specific stuff. Based on doit's implementation.
+# (see Issue #3342)
+def _command_help(self: Command):
+    """Return help text for a command."""
+    text = []
+
+    usage = "{} {} {}".format(self.bin_name, self.name, self.doc_usage)
+    text.extend(textwrap.wrap(usage, subsequent_indent='  '))
+    text.extend(_wrap(self.doc_purpose, 4))
+
+    text.append("\nOptions:")
+    options = defaultdict(list)
+    for opt in self.cmdparser.options:
+        options[opt.section].append(opt)
+    for section, opts in sorted(options.items()):
+        if section:
+            section_name = '\n{}'.format(section)
+            text.extend(_wrap(section_name, 2))
+        for opt in opts:
+            # ignore option that cant be modified on cmd line
+            if not (opt.short or opt.long):
+                continue
+            text.extend(_wrap(opt.help_param(), 4))
+            opt_help = opt.help
+            if '%(default)s' in opt_help:
+                opt_help = opt.help % {'default': opt.default}
+            elif opt.default != '' and opt.default is not False and opt.default is not None:
+                opt_help += ' [default: {}]'.format(opt.default)
+            opt_choices = opt.help_choices()
+            desc = '{} {}'.format(opt_help, opt_choices)
+            text.extend(_wrap(desc, 8))
+
+            # print bool inverse option
+            if opt.inverse:
+                text.extend(_wrap('--{}'.format(opt.inverse), 4))
+                text.extend(_wrap('opposite of --{}'.format(opt.long), 8))
+
+    if self.doc_description is not None:
+        text.append("\n\nDescription:")
+        text.extend(_wrap(self.doc_description, 4))
+    return "\n".join(text)
+
+
+doit.cmd_base.Command.help = _command_help
+
+
 def levenshtein(s1, s2):
     u"""Calculate the Levenshtein distance of two strings.
 
