@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2020 Roberto Alsina and others.
+# Copyright © 2012-2021 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -98,6 +98,9 @@ class BasePlugin(IPlugin):
         """Find the dependencies for a file."""
         return []
 
+    def register_auto_watched_folder(self, folder: str) -> None:
+        self.site.registered_auto_watched_folders.add(folder)
+
 
 class PostScanner(BasePlugin):
     """The scan method of these plugins is called by Nikola.scan_posts."""
@@ -119,7 +122,7 @@ class Command(BasePlugin, DoitCommand):
     doc_purpose = "A short explanation."
     doc_usage = ""
     doc_description = None  # None value will completely omit line from doc
-    # see http://python-doit.sourceforge.net/cmd_run.html#parameters
+    # see https://pydoit.org/cmd_run.html#parameters
     cmd_options = ()
     needs_config = True
 
@@ -302,7 +305,7 @@ class PageCompiler(BasePlugin):
         def create_lambda(lang: str) -> 'typing.Callable':
             # We create a lambda like this so we can pass `lang` to it, because if we didn’t
             # add that function, `lang` would always be the last language in TRANSLATIONS.
-            # (See http://docs.python-guide.org/en/latest/writing/gotchas/#late-binding-closures)
+            # (See https://docs.python-guide.org/writing/gotchas/#late-binding-closures)
             return lambda: self._read_extra_deps(post, lang)
 
         for lang in self.site.config['TRANSLATIONS']:
