@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2020 Roberto Alsina and others.
+# Copyright © 2012-2021 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -140,7 +140,7 @@ class CommandPlugin(Command):
                 user_mode = True
 
             if user_mode:
-                self.output_dir = os.path.expanduser('~/.nikola/plugins')
+                self.output_dir = os.path.expanduser(os.path.join('~', '.nikola', 'plugins'))
             else:
                 self.output_dir = 'plugins'
 
@@ -255,7 +255,7 @@ class CommandPlugin(Command):
             except subprocess.CalledProcessError:
                 LOGGER.error('Could not install the dependencies.')
                 print('Contents of the requirements.txt file:\n')
-                with io.open(reqpath, 'r', encoding='utf-8') as fh:
+                with io.open(reqpath, 'r', encoding='utf-8-sig') as fh:
                     print(utils.indent(fh.read(), 4 * ' '))
                 print('You have to install those yourself or through a '
                       'package manager.')
@@ -268,7 +268,7 @@ class CommandPlugin(Command):
                            'dependencies you need to install '
                            'manually.')
             print('Contents of the requirements-nonpy.txt file:\n')
-            with io.open(reqnpypath, 'r', encoding='utf-8') as fh:
+            with io.open(reqnpypath, 'r', encoding='utf-8-sig') as fh:
                 for l in fh.readlines():
                     i, j = l.split('::')
                     print(utils.indent(i.strip(), 4 * ' '))
@@ -284,7 +284,7 @@ class CommandPlugin(Command):
             LOGGER.info('Installing plugins...')
             plugin_failure = False
             try:
-                with io.open(req_plug_path, 'r', encoding='utf-8') as inf:
+                with io.open(req_plug_path, 'r', encoding='utf-8-sig') as inf:
                     for plugname in inf.readlines():
                         plugin_failure = self.do_install(url, plugname.strip(), show_install_notes) != 0
             except Exception:
@@ -292,7 +292,7 @@ class CommandPlugin(Command):
             if plugin_failure:
                 LOGGER.error('Could not install a plugin.')
                 print('Contents of the requirements-plugins.txt file:\n')
-                with io.open(req_plug_path, 'r', encoding='utf-8') as fh:
+                with io.open(req_plug_path, 'r', encoding='utf-8-sig') as fh:
                     print(utils.indent(fh.read(), 4 * ' '))
                 print('You have to install those yourself manually.')
             else:
@@ -302,7 +302,7 @@ class CommandPlugin(Command):
         if os.path.exists(confpypath) and show_install_notes:
             LOGGER.warning('This plugin has a sample config file.  Integrate it with yours in order to make this plugin work!')
             print('Contents of the conf.py.sample file:\n')
-            with io.open(confpypath, 'r', encoding='utf-8') as fh:
+            with io.open(confpypath, 'r', encoding='utf-8-sig') as fh:
                 if self.site.colorful:
                     print(pygments.highlight(fh.read(), PythonLexer(), TerminalFormatter()))
                 else:
